pub struct LambdaInvocation {
pub parts: Parts,
pub body: Bytes,
pub context: Context,
}Expand description
A simple container that provides information about a single invocation of a Lambda function.
Fields
parts: PartsThe header of the request sent to invoke the Lambda function.
body: BytesThe body of the request sent to invoke the Lambda function.
context: ContextThe context of the Lambda invocation.